.. PgQueuer documentation master file, created by
   sphinx-quickstart on Fri May 31 20:52:43 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PgQueuer's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   database_initialization
   queuemanager
   dashboard
   benchmark

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
